"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractQueueService = void 0;
const node_util_1 = require("node:util");
const node_core_1 = require("@lokalise/node-core");
class AbstractQueueService {
    errorReporter;
    logger;
    messageTypeField;
    logMessages;
    creationConfig;
    locatorConfig;
    deletionConfig;
    constructor({ errorReporter, logger }, options) {
        this.errorReporter = errorReporter;
        this.logger = logger;
        this.messageTypeField = options.messageTypeField;
        this.creationConfig = options.creationConfig;
        this.locatorConfig = options.locatorConfig;
        this.deletionConfig = options.deletionConfig;
        this.logMessages = options.logMessages ?? false;
    }
    /**
     * Format message for logging
     */
    resolveMessageLog(message, _messageType) {
        return message;
    }
    /**
     * Log preformatted and potentially presanitized message payload
     */
    logMessage(messageLogEntry) {
        this.logger.debug(messageLogEntry);
    }
    handleError(err) {
        const logObject = (0, node_core_1.resolveGlobalErrorLogObject)(err);
        this.logger.error(logObject);
        if (node_util_1.types.isNativeError(err)) {
            this.errorReporter.report({ error: err });
        }
    }
}
exports.AbstractQueueService = AbstractQueueService;
//# sourceMappingURL=AbstractQueueService.js.map